"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator.throw(value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments)).next());
    });
};
const sinon = require('sinon');
const mongo_entity_1 = require('../mongo_entity');
const testing_1 = require('../testing');
const assert = require('power-assert');
describe('Testing Helpers', () => {
    describe('withContext', () => {
        it('initializes context with connection, executes tests and cleans up afterwards', function () {
            return __awaiter(this, void 0, void 0, function* () {
                function initContext(conn) {
                    return {
                        entity: new mongo_entity_1.default(conn, 'col'),
                        other: {}
                    };
                }
                let inContext = null;
                let deleteSpy = null;
                yield testing_1.withContext(initContext, (context) => __awaiter(this, void 0, void 0, function* () {
                    assert(context.entity);
                    deleteSpy = sinon.spy(context.entity, 'delete');
                    inContext = context;
                }));
                sinon.assert.calledOnce(deleteSpy);
            });
        });
        it('throws exception but also cleans up', function () {
            return __awaiter(this, void 0, void 0, function* () {
                function initContext(conn) {
                    return {
                        entity: new mongo_entity_1.default(conn, 'col'),
                    };
                }
                let inContext = null;
                let deleteSpy = null;
                try {
                    yield testing_1.withContext(initContext, (context) => __awaiter(this, void 0, void 0, function* () {
                        deleteSpy = sinon.spy(context.entity, 'delete');
                        inContext = context;
                        throw new Error('Error');
                    }));
                }
                catch (ex) {
                    assert.equal(ex.message, 'Error');
                }
                sinon.assert.calledOnce(deleteSpy);
            });
        });
    });
});
